<?php

namespace Drupal\typogrify\TwigExtension;


use Drupal\typogrify\SmartyPants;

class Typogrify extends \Twig_Extension {

  public function getFilters() {
    return [
      new \Twig_SimpleFilter('typogrify', [$this, 'filter'], ['is_safe' => ['html']]),
    ];
  }

  /**
   * Filter text by Typogrify.
   *
   * @param $text
   * @param string[] $options
   *   Filters to be used for filtering. If empty, all filters will be used.
   *   Possible values: amp, widont, smartypants, caps, initial_quotes, dash
   * @return string
   *   The filtered string.
   */
  public static function filter($text, $options = []) {
    if (empty($options)) {
      return \Drupal\typogrify\Typogrify::filter($text);
    }

    if (in_array('amp', $options)) {
      $text = \Drupal\typogrify\Typogrify::amp($text);
    }

    if (in_array('widont', $options)) {
      $text = \Drupal\typogrify\Typogrify::widont($text);
    }

    if (in_array('smartypants', $options)) {
      $text = SmartyPants::process($text);
    }

    if (in_array('caps', $options)) {
      $text = \Drupal\typogrify\Typogrify::caps($text);
    }

    if (in_array('initial_quotes', $options)) {
      $text = \Drupal\typogrify\Typogrify::initial_quotes($text);
    }

    if (in_array('dash', $options)) {
      $text = \Drupal\typogrify\Typogrify::dash($text);
    }

    return $text;
  }
}
